@@ -39,10 +39,10 @@ int main(int argc, char *argv[])
                          i18n("A tool that emits a notification for all users by sending it on the system DBus"),
                          KAboutLicense::GPL,
                          i18n("(c) 2016 Kai Uwe Broulik"));
+    KAboutData::setApplicationData(aboutData);
 
     QCommandLineParser parser;
-    parser.addHelpOption();
-    parser.addVersionOption();
+    aboutData.setupCommandLine(&parser);
 
     QCommandLineOption applicationNameOption(QStringLiteral("application"), i18n("Name of the application that should be associated with this notification"), QStringLiteral("application"));
     parser.addOption(applicationNameOption);
@@ -57,8 +57,6 @@ int main(int argc, char *argv[])
     QCommandLineOption persistentOption(QStringLiteral("persistent"), i18n("Keep the notification in the history until the user closes it"));
     parser.addOption(persistentOption);
 
-    aboutData.setupCommandLine(&parser);
-
     parser.addPositionalArgument(QStringLiteral("body"), i18n("The actual notification body text"));
 
     parser.process(app);
